"""Handle logging."""

import logging
import sys


def get_file_logger(name: str) -> logging.Logger:
    """Return a file logger.

    :param name: arbitrary name
    :type name: str
    :rtype: logging.Logger
    """
    # formatter
    items = [
        "%(name)s: %(asctime)s",
        "%(levelname)s",
        "%(filename)s:%(lineno)s",
        "%(process)d >>> %(message)s",
    ]
    template = " | ".join(items)
    formatter = logging.Formatter(template)
    # handler
    out_handler = logging.StreamHandler(stream=sys.stdout)
    out_handler.setFormatter(formatter)
    out_handler.setLevel(logging.INFO)
    # logger
    logger = logging.getLogger(name)
    logger.addHandler(out_handler)
    logger.setLevel(logging.INFO)
    return logger


def get_stream_logger(level: int) -> logging.Logger:
    """Return a stream logger.

    :param level: filtering level
    :type level: int
    :rtype: logging.Logger
    """
    # handler
    out_handler = logging.StreamHandler(stream=sys.stdout)
    out_handler.setLevel(level)
    # logger
    logger = logging.getLogger()
    logger.addHandler(out_handler)
    logger.setLevel(level)
    return logger


stream = get_stream_logger(logging.INFO)
